@@ -1,6 +1,8 @@
 import sys
 import urllib
 
+import django
+
 PY3 = sys.version_info[0] == 3
 
 if PY3:
@@ -30,4 +32,13 @@ else:
         return urllib.unquote(s).decode('utf8')
 
 
+def is_authenticated(user):
+    if django.VERSION < (1, 10):
+        return user.is_authenticated()
+    return user.is_authenticated
 
+
+def is_anonymous(user):
+    if django.VERSION < (1, 10):
+        return user.is_anonymous()
+    return user.is_anonymous
